@@ -7,31 +7,26 @@ from reqif.helpers.debug import auto_described
 class ReqIFDataTypeDefinitionString:
     def __init__(  # pylint: disable=too-many-arguments
         self,
-        is_self_closed: bool,
-        description: Optional[str],
         identifier: str,
-        last_change: Optional[str],
-        long_name: Optional[str],
-        max_length: Optional[str],
+        description: Optional[str] = None,
+        last_change: Optional[str] = None,
+        long_name: Optional[str] = None,
+        max_length: Optional[str] = None,
+        is_self_closed: bool = True,
     ):
-        self.is_self_closed: bool = is_self_closed
-        self.description: Optional[str] = description
         self.identifier: str = identifier
+        self.description: Optional[str] = description
         self.last_change: Optional[str] = last_change
         self.long_name: Optional[str] = long_name
         self.max_length: Optional[str] = max_length
+        self.is_self_closed: bool = is_self_closed
 
     @staticmethod
     def create(
         identifier: str,
     ) -> "ReqIFDataTypeDefinitionString":
         return ReqIFDataTypeDefinitionString(
-            is_self_closed=True,
-            description=None,
             identifier=identifier,
-            last_change=None,
-            long_name=None,
-            max_length=None,
         )
 
 
@@ -39,28 +34,24 @@ class ReqIFDataTypeDefinitionString:
 class ReqIFDataTypeDefinitionBoolean:
     def __init__(  # pylint: disable=too-many-arguments
         self,
-        is_self_closed: bool,
-        description: Optional[str],
         identifier: str,
-        last_change: Optional[str],
-        long_name: Optional[str],
+        description: Optional[str] = None,
+        last_change: Optional[str] = None,
+        long_name: Optional[str] = None,
+        is_self_closed: bool = True,
     ):
-        self.is_self_closed: bool = is_self_closed
-        self.description: Optional[str] = description
         self.identifier: str = identifier
+        self.description: Optional[str] = description
         self.last_change: Optional[str] = last_change
         self.long_name: Optional[str] = long_name
+        self.is_self_closed: bool = is_self_closed
 
     @staticmethod
     def create(
         identifier: str,
     ) -> "ReqIFDataTypeDefinitionBoolean":
         return ReqIFDataTypeDefinitionBoolean(
-            is_self_closed=True,
-            description=None,
             identifier=identifier,
-            last_change=None,
-            long_name=None,
         )
 
 
@@ -68,73 +59,69 @@ class ReqIFDataTypeDefinitionBoolean:
 class ReqIFDataTypeDefinitionInteger:
     def __init__(  # pylint: disable=too-many-arguments
         self,
-        is_self_closed: bool,
-        description: Optional[str],
         identifier: str,
-        last_change: Optional[str],
-        long_name: str,
-        max_value: Optional[str],
-        min_value: Optional[str],
+        description: Optional[str] = None,
+        last_change: Optional[str] = None,
+        long_name: Optional[str] = None,
+        max_value: Optional[str] = None,
+        min_value: Optional[str] = None,
+        is_self_closed: bool = True,
     ):
-        self.is_self_closed: bool = is_self_closed
-        self.description: Optional[str] = description
         self.identifier: str = identifier
+        self.description: Optional[str] = description
         self.last_change: Optional[str] = last_change
-        self.long_name: str = long_name
+        self.long_name: Optional[str] = long_name
         self.max_value: Optional[str] = max_value
         self.min_value: Optional[str] = min_value
+        self.is_self_closed: bool = is_self_closed
 
 
 @auto_described
 class ReqIFDataTypeDefinitionReal:  # pylint: disable=too-many-instance-attributes  # noqa: E501
     def __init__(  # pylint: disable=too-many-arguments
         self,
-        is_self_closed: bool,
-        accuracy: Optional[int],
-        description: Optional[str],
         identifier: str,
-        last_change: Optional[str],
-        long_name: Optional[str],
-        max_value: Optional[str],
-        min_value: Optional[str],
+        accuracy: Optional[int] = None,
+        description: Optional[str] = None,
+        last_change: Optional[str] = None,
+        long_name: Optional[str] = None,
+        max_value: Optional[str] = None,
+        min_value: Optional[str] = None,
+        is_self_closed: bool = False,
     ):
-        self.is_self_closed: bool = is_self_closed
+        self.identifier: str = identifier
         self.accuracy: Optional[int] = accuracy
         self.description: Optional[str] = description
-        self.identifier: str = identifier
         self.last_change: Optional[str] = last_change
         self.long_name: Optional[str] = long_name
         self.max_value: Optional[str] = max_value
         self.min_value: Optional[str] = min_value
+        self.is_self_closed: bool = is_self_closed
 
 
 @auto_described
 class ReqIFEnumValue:
     def __init__(  # pylint: disable=too-many-arguments
         self,
-        description: Optional[str],
         identifier: str,
-        last_change: Optional[str],
         key: str,
-        other_content: Optional[str],
-        long_name: Optional[str],
+        description: Optional[str] = None,
+        last_change: Optional[str] = None,
+        other_content: Optional[str] = None,
+        long_name: Optional[str] = None,
     ):
-        self.description: Optional[str] = description
         self.identifier: str = identifier
-        self.last_change: Optional[str] = last_change
         self.key: str = key
+        self.description: Optional[str] = description
+        self.last_change: Optional[str] = last_change
         self.other_content: Optional[str] = other_content
         self.long_name: Optional[str] = long_name
 
     @staticmethod
     def create(identifier: str, key: str):
         return ReqIFEnumValue(
-            description=None,
             identifier=identifier,
-            last_change=None,
             key=key,
-            other_content=None,
-            long_name=None,
         )
 
 
@@ -142,17 +129,16 @@ class ReqIFEnumValue:
 class ReqIFDataTypeDefinitionEnumeration:  # pylint: disable=too-many-instance-attributes # noqa: E501
     def __init__(  # pylint: disable=too-many-arguments
         self,
-        is_self_closed: bool,
-        description: Optional[str],
         identifier: str,
-        last_change: Optional[str],
-        long_name: Optional[str],
-        multi_valued: Optional[bool],
-        values: Optional[List[ReqIFEnumValue]],
+        description: Optional[str] = None,
+        last_change: Optional[str] = None,
+        long_name: Optional[str] = None,
+        multi_valued: Optional[bool] = None,
+        values: Optional[List[ReqIFEnumValue]] = None,
+        is_self_closed: bool = False,
     ):
-        self.is_self_closed: bool = is_self_closed
+        self.identifier: str = identifier
         self.description: Optional[str] = description
-        self.identifier = identifier
         self.last_change: Optional[str] = last_change
         self.long_name: Optional[str] = long_name
         self.multi_valued: Optional[bool] = multi_valued
@@ -161,16 +147,12 @@ class ReqIFDataTypeDefinitionEnumeration:  # pylint: disable=too-many-instance-a
         if values is not None:
             for value in values:
                 self.values_map[value.identifier] = value.key
+        self.is_self_closed: bool = is_self_closed
 
     @staticmethod
     def create(identifier: str, values: Optional[List[ReqIFEnumValue]]):
         return ReqIFDataTypeDefinitionEnumeration(
-            is_self_closed=False,
-            description=None,
             identifier=identifier,
-            last_change=None,
-            long_name=None,
-            multi_valued=False,
             values=values,
         )
 
@@ -179,31 +161,31 @@ class ReqIFDataTypeDefinitionEnumeration:  # pylint: disable=too-many-instance-a
 class ReqIFDataTypeDefinitionXHTML:
     def __init__(  # pylint: disable=too-many-arguments
         self,
-        is_self_closed: bool,
-        description: Optional[str],
         identifier: str,
-        last_change: Optional[str],
-        long_name: Optional[str],
+        description: Optional[str] = None,
+        last_change: Optional[str] = None,
+        long_name: Optional[str] = None,
+        is_self_closed: bool = False,
     ):
-        self.is_self_closed: bool = is_self_closed
-        self.description: Optional[str] = description
         self.identifier: str = identifier
+        self.description: Optional[str] = description
         self.last_change: Optional[str] = last_change
         self.long_name: Optional[str] = long_name
+        self.is_self_closed: bool = is_self_closed
 
 
 @auto_described
 class ReqIFDataTypeDefinitionDateIdentifier:
     def __init__(  # pylint: disable=too-many-arguments
         self,
-        is_self_closed: bool,
-        description: Optional[str],
         identifier: str,
-        last_change: Optional[str],
-        long_name: Optional[str],
+        description: Optional[str] = None,
+        last_change: Optional[str] = None,
+        long_name: Optional[str] = None,
+        is_self_closed: bool = True,
     ):
-        self.is_self_closed: bool = is_self_closed
-        self.description: Optional[str] = description
         self.identifier: str = identifier
+        self.description: Optional[str] = description
         self.last_change: Optional[str] = last_change
         self.long_name: Optional[str] = long_name
+        self.is_self_closed: bool = is_self_closed
