@@ -1,4 +1,4 @@
-from typing import Dict, List, Any
+from typing import Any, Dict, List
 
 from reqif.helpers.debug import auto_described
 from reqif.models.reqif_spec_object import ReqIFSpecObject
